sqltriples.Query.Intersection

Package sqltriples :: Module Query :: Class Intersection |
[show private | hide private]
[frames | no frames]

## Class Intersection

        CombinedResults --+
                          |
    CombinedTopLevelResults --+
                              |
                             Intersection

Known Subclasses:
  `IntersectionOfObjects`, `IntersectionOfPredicates`, `IntersectionOfSubjects`, `IntersectionOfTriples`, `IntersectionOfTuples`

Method Summary
Inherited from CombinedTopLevelResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`

Class Variable Summary
`int` | `in_parentheses` = 0
`str` | `operator` = `'intersect'`

Class Variable Details

    ### in_parentheses Type: `int` Value:
        0

    ### operator Type: `str` Value:
        'intersect'

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net